<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output omit-xml-declaration="yes" indent="yes" />
    <xsl:strip-space elements="*" />

    <xsl:template match="integrationData">
        <xsl:copy>
            <xsl:attribute name="version">
                <xsl:value-of select="current()/@version" />
            </xsl:attribute>
            <xsl:apply-templates select="job" />
            <xsl:element name="placedOrders">
                <xsl:apply-templates select="placedOrders" />
            </xsl:element>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="integrationData/job">
        <xsl:element name="job">
            <xsl:apply-templates select="authority" />
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/job/authority">
        <xsl:element name="authority">
            <xsl:element name="authorityId">
                <xsl:value-of select="authorityId" />
            </xsl:element>
            <xsl:element name="authorityType">
                <xsl:value-of select="authorityType" />
            </xsl:element>
            <xsl:element name="dataOriginJobId">
                <xsl:value-of select="dataOriginJobId" />
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order">
            <xsl:element name="order">
                <xsl:element name="orderId">
                    <xsl:value-of select="orderId" />
                </xsl:element>
                <xsl:element name="accountId">
                    <xsl:value-of select="accountId" />
                </xsl:element>
                <xsl:element name="shopId">
                    <xsl:value-of select="shopId" />
                </xsl:element>
                <xsl:element name="shopGroupId">
                    <xsl:value-of select="shopGroupId" />
                </xsl:element>
                <xsl:element name="dataOrigin">
                    <xsl:apply-templates select="dataOrigin" />
                </xsl:element>
                <xsl:element name="date">
                    <xsl:value-of select="date" />
                </xsl:element>
                <xsl:element name="dateReady">
                    <xsl:value-of select="dateReady" />
                </xsl:element>
                <xsl:element name="currencyId">
                    <xsl:value-of select="currencyId" />
                </xsl:element>
                <xsl:element name="languageId">
                    <xsl:value-of select="languageId" />
                </xsl:element>
                <xsl:element name="salespersonId">
                    <xsl:value-of select="salespersonId" />
                </xsl:element>
                <xsl:element name="orderRemarks">
                    <xsl:value-of select="orderRemarks" />
                </xsl:element>
                <xsl:element name="sellTo">
                    <xsl:apply-templates select="sellTo" />
                </xsl:element>
                <xsl:apply-templates select="billTo" />
                <xsl:apply-templates select="deliveryAddress" />
                <xsl:element name="payments">
                    <xsl:apply-templates select="payments/payment" />
                </xsl:element>
                <xsl:element name="shipment">
                    <xsl:apply-templates select="shipment" />
                </xsl:element>
                <xsl:element name="parcelCollect">
                    <xsl:apply-templates select="parcelCollect" />
                </xsl:element>
                <xsl:element name="orderLines">
                    <xsl:apply-templates select="orderLines/line" />
                </xsl:element>
                <xsl:element name="posId">
                    <xsl:value-of select="posId" />
                </xsl:element>
                <xsl:element name="barcode">
                    <xsl:value-of select="barcode" />
                </xsl:element>
                <xsl:element name="locationId">
                    <xsl:value-of select="locationId" />
                </xsl:element>
				<xsl:element name="priceListId">
                    <xsl:value-of select="priceListId" />
                </xsl:element>
				<xsl:element name="isInventoryCheckSuspended">
                    <xsl:value-of select="isInventoryCheckSuspended" />
                </xsl:element>
				<xsl:element name="priceCalculationDate">
                    <xsl:value-of select="priceCalculationDate" />
                </xsl:element>
                <xsl:if test="userValues!=''">
                    <xsl:element name="userValues">
                        <xsl:apply-templates select="userValues/userValue" />
                    </xsl:element>
                </xsl:if>

            </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/dataOrigin">
        <!-- <xsl:if test="shopId">
            <xsl:element name="shopId">
                <xsl:value-of select="shopId" />
            </xsl:element>
        </xsl:if> -->
		<xsl:for-each select="shopId">
			<xsl:element name="shopId">
                <xsl:value-of select="." />
            </xsl:element>
		</xsl:for-each>
    </xsl:template>
    <xsl:template match="integrationData/placedOrders/order/billTo">
        <xsl:element name="billTo">
            <xsl:element name="customerId">
                <xsl:value-of select="customerId" />
            </xsl:element>
            <xsl:element name="lifeTimeId">
                <xsl:value-of select="lifeTimeId" />
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/deliveryAddress">
        <xsl:element name="deliveryAddress">
			<xsl:element name="deliveryAddressId">
				<xsl:value-of select="deliveryAddressId"/>
			</xsl:element>
            <xsl:element name="name">
                <xsl:value-of select="name" />
            </xsl:element>
            <xsl:element name="name2">
                <xsl:value-of select="name2" />
            </xsl:element>
            <xsl:element name="address">
                <xsl:value-of select="address" />
            </xsl:element>
            <xsl:element name="address2">
                <xsl:value-of select="address2" />
            </xsl:element>
            <xsl:element name="city">
                <xsl:value-of select="city" />
            </xsl:element>
            <xsl:element name="contact">
                <xsl:value-of select="contact" />
            </xsl:element>
            <xsl:element name="postCode">
                <xsl:value-of select="postCode" />
            </xsl:element>
            <xsl:element name="county">
                <xsl:value-of select="county" />
            </xsl:element>
            <xsl:element name="countryId">
                <xsl:value-of select="countryId" />
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/sellTo">
        <xsl:element name="lifeTimeId">
            <xsl:value-of select="lifeTimeId" />
        </xsl:element>
        <xsl:element name="customerId">
            <xsl:value-of select="customerId" />
        </xsl:element>
        <xsl:element name="userName">
            <xsl:value-of select="userName" />
        </xsl:element>
        <xsl:element name="customerVatGroupId">
            <xsl:value-of select="customerVatGroupId" />
        </xsl:element>
        <xsl:element name="customerPriceGroupId">
            <xsl:value-of select="customerPriceGroupId" />
        </xsl:element>
        <xsl:element name="customerDiscountGroupId">
            <xsl:value-of select="customerDiscountGroupId" />
        </xsl:element>
        <xsl:element name="salesTaxRegistrationNumber">
            <xsl:value-of select="salesTaxRegistrationNumber" />
        </xsl:element>
        <xsl:element name="name">
            <xsl:value-of select="name" />
        </xsl:element>
        <xsl:element name="name2">
            <xsl:value-of select="name2" />
        </xsl:element>
        <xsl:element name="address">
            <xsl:value-of select="address" />
        </xsl:element>
        <xsl:element name="address2">
            <xsl:value-of select="address2" />
        </xsl:element>
        <xsl:element name="city">
            <xsl:value-of select="city" />
        </xsl:element>
        <xsl:element name="contact">
            <xsl:value-of select="contact" />
        </xsl:element>
        <xsl:element name="postCode">
            <xsl:value-of select="postCode" />
        </xsl:element>
        <xsl:element name="county">
            <xsl:value-of select="county" />
        </xsl:element>
        <xsl:element name="countryId">
            <xsl:value-of select="countryId" />
        </xsl:element>
        <xsl:element name="phoneNumber">
            <xsl:value-of select="phoneNumber" />
        </xsl:element>
        <xsl:element name="mobilePhoneNo">
            <xsl:value-of select="mobilePhoneNo" />
        </xsl:element>
        <xsl:element name="email">
            <xsl:value-of select="email" />
        </xsl:element>
        <xsl:element name="yourReference">
            <xsl:value-of select="yourReference" />
        </xsl:element>
        <xsl:element name="faxNumber">
            <xsl:value-of select="faxNumber" />
        </xsl:element>
        <xsl:element name="eanNumber">
            <xsl:value-of select="eanNumber" />
        </xsl:element>
        <xsl:element name="eanAccountNumber">
            <xsl:value-of select="eanAccountNumber" />
        </xsl:element>
        <xsl:element name="eanReference">
            <xsl:value-of select="eanReference" />
        </xsl:element>
    </xsl:template>

    <xsl:template match="payments/payment">
        <xsl:element name="payment">
            <xsl:element name="paymentMethodId">
                <xsl:value-of select="paymentMethodId" />
            </xsl:element>
            <xsl:element name="description">
                <xsl:value-of select="description" />
            </xsl:element>
            <xsl:if test="productVatGroupId!=''">
                <xsl:element name="productVatGroupId">
                    <xsl:value-of select="productVatGroupId" />
                </xsl:element>
            </xsl:if>
            <xsl:element name="amountExVat">
                <xsl:value-of select="amountExVat" />
            </xsl:element>
            <xsl:element name="vatAmount">
                <xsl:value-of select="vatAmount" />
            </xsl:element>
            <xsl:element name="vatPercentage">
                <xsl:value-of select="vatPercentage" />
            </xsl:element>
            <xsl:element name="amountIncVat">
                <xsl:value-of select="amountIncVat" />
            </xsl:element>
            <xsl:element name="paymentProvider">
                <xsl:element name="name">
                    <xsl:value-of select="paymentProvider/name" />
                </xsl:element>
                <xsl:element name="reservedAmount">
                    <xsl:value-of select="paymentProvider/reservedAmount" />
                </xsl:element>
                <xsl:element name="transactionId">
                    <xsl:value-of select="paymentProvider/transactionId" />
                </xsl:element>
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/shipment">
        <xsl:element name="shipmentMethodId">
            <xsl:value-of select="shipmentMethodId" />
        </xsl:element>
        <xsl:element name="requestedDeliveryDate">
            <xsl:value-of select="requestedDeliveryDate" />
        </xsl:element>
        <xsl:element name="description">
            <xsl:value-of select="description" />
        </xsl:element>
        <xsl:if test="productVatGroupId!=''">
            <xsl:element name="productVatGroupId">
                <xsl:value-of select="productVatGroupId" />
            </xsl:element>
        </xsl:if>
        <xsl:element name="amountExVat">
            <xsl:value-of select="amountExVat" />
        </xsl:element>
        <xsl:element name="vatAmount">
            <xsl:value-of select="vatAmount" />
        </xsl:element>
        <xsl:element name="vatPercentage">
            <xsl:value-of select="vatPercentage" />
        </xsl:element>
        <xsl:element name="amountIncVat">
            <xsl:value-of select="amountIncVat" />
        </xsl:element>
        <xsl:element name="shipmentProvider">
            <xsl:element name="name">
                <xsl:value-of select="shipmentProvider/name" />
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/parcelCollect">
        <xsl:element name="carrierId">
            <xsl:value-of select="carrierId" />
        </xsl:element>
        <xsl:element name="barcode">
            <xsl:value-of select="barcode" />
        </xsl:element>
        <xsl:if test="service">
            <xsl:apply-templates select="service" />
        </xsl:if>
        <xsl:if test="destination">
            <xsl:apply-templates select="destination" />
        </xsl:if>
        <xsl:if test="notification">
            <xsl:apply-templates select="notification" />
        </xsl:if>
        <xsl:if test="instructions">
            <xsl:apply-templates select="instructions" />
        </xsl:if>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/parcelCollect/service">
        <xsl:element name="service">
            <xsl:element name="parcelType">
                <xsl:value-of select="parcelType" />
            </xsl:element>
            <xsl:element name="shipmentType">
                <xsl:value-of select="shipmentType" />
            </xsl:element>
        </xsl:element>
    </xsl:template>


    <xsl:template match="integrationData/placedOrders/order/parcelCollect/notification">
        <xsl:element name="notification">
            <xsl:element name="smsNumber">
                <xsl:value-of select="smsNumber" />
            </xsl:element>
            <xsl:element name="emailAddress">
                <xsl:value-of select="emailAddress" />
            </xsl:element>
        </xsl:element>
    </xsl:template>


    <xsl:template match="integrationData/placedOrders/order/parcelCollect/instructions">
        <xsl:element name="instructions">
            <xsl:if test="leaveUnattended">
                <xsl:element name="leaveUnattended">
                    <xsl:value-of select="leaveUnattended" />
                </xsl:element>
            </xsl:if>
            <xsl:if test="remarks">
                <xsl:element name="remarks">
                    <xsl:value-of select="remarks" />
                </xsl:element>
            </xsl:if>
            <xsl:if test="deliveryDate">
                <xsl:element name="deliveryDate">
                    <xsl:value-of select="deliveryDate" />
                </xsl:element>
            </xsl:if>
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/parcelCollect/destination">
        <xsl:element name="destination">
            <xsl:element name="id">
                <xsl:value-of select="id" />
            </xsl:element>
            <xsl:element name="name">
                <xsl:value-of select="name" />
            </xsl:element>
            <xsl:element name="name2">
                <xsl:value-of select="name2" />
            </xsl:element>
            <xsl:element name="address">
                <xsl:value-of select="address" />
            </xsl:element>
            <xsl:element name="address2">
                <xsl:value-of select="address2" />
            </xsl:element>
            <xsl:element name="city">
                <xsl:value-of select="city" />
            </xsl:element>
            <xsl:element name="postCode">
                <xsl:value-of select="postCode" />
            </xsl:element>
            <xsl:element name="county">
                <xsl:value-of select="county" />
            </xsl:element>
            <xsl:element name="countryId">
                <xsl:value-of select="countryId" />
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <xsl:template match="integrationData/placedOrders/order/orderLines/line">
        <xsl:element name="line">
            <xsl:attribute name="id">
                <xsl:value-of select="current()/@id" />
            </xsl:attribute>
            <xsl:element name="lineTypeId">
                <xsl:value-of select="lineTypeId" />
            </xsl:element>
            <xsl:element name="parentLineId">
                <xsl:value-of select="parentLineId" />
            </xsl:element>
            <xsl:element name="itemId">
                <xsl:value-of select="itemId" />
            </xsl:element>
            <xsl:element name="variantId">
                <xsl:value-of select="variantId" />
            </xsl:element>
            <xsl:element name="eanNumber">
                <xsl:value-of select="eanNumber" />
            </xsl:element>
            <xsl:element name="lineDescription1">
                <xsl:value-of select="lineDescription1" />
            </xsl:element>
            <xsl:element name="lineDescription2">
                <xsl:value-of select="lineDescription2" />
            </xsl:element>
            <xsl:element name="lineDescription3">
                <xsl:value-of select="lineDescription3" />
            </xsl:element>
            <xsl:element name="productVatGroupId">
                <xsl:value-of select="productVatGroupId" />
            </xsl:element>
            <xsl:element name="manufacturerSKU">
                <xsl:value-of select="manufacturerSKU" />
            </xsl:element>
            <xsl:element name="quantity">
                <xsl:value-of select="quantity" />
            </xsl:element>
            <xsl:element name="vatPercentage">
                <xsl:value-of select="vatPercentage" />
            </xsl:element>
            <xsl:element name="unitBasePriceExVat">
                <xsl:value-of select="unitBasePriceExVat" />
            </xsl:element>
            <xsl:element name="unitBasePriceIncVat">
                <xsl:value-of select="unitBasePriceIncVat" />
            </xsl:element>
            <xsl:element name="unitPriceExVat">
                <xsl:value-of select="unitPriceExVat" />
            </xsl:element>
            <xsl:element name="unitPriceVatAmount">
                <xsl:value-of select="unitPriceVatAmount" />
            </xsl:element>
            <xsl:element name="unitPriceDiscountAmountExVat">
                <xsl:value-of select="unitPriceDiscountAmountExVat" />
            </xsl:element>
            <xsl:element name="unitPriceDiscountPercent">
                <xsl:value-of select="unitPriceDiscountPercent" />
            </xsl:element>
            <xsl:element name="unitPriceIncVat">
                <xsl:value-of select="unitPriceIncVat" />
            </xsl:element>
            <xsl:element name="lineAmountExVat">
                <xsl:value-of select="lineAmountExVat" />
            </xsl:element>
            <xsl:element name="lineAmountIncVat">
                <xsl:value-of select="lineAmountIncVat" />
            </xsl:element>
			<xsl:element name="isAmountInTotals">
                <xsl:value-of select="isAmountInTotals" />
            </xsl:element>
			<xsl:element name="isSumLine">
                <xsl:value-of select="isSumLine" />
            </xsl:element>
            <xsl:element name="costPrice">
                <xsl:value-of select="costPrice" />
            </xsl:element>
            <xsl:element name="sortOrder">
                <xsl:value-of select="sortOrder" />
            </xsl:element>
			<xsl:element name="posId">
                <xsl:value-of select="posId" />
            </xsl:element>
			<xsl:element name="userCode1">
                <xsl:value-of select="userCode1" />
            </xsl:element>
			<xsl:element name="userCode2">
                <xsl:value-of select="userCode2" />
            </xsl:element>
			<xsl:element name="userCode3">
                <xsl:value-of select="userCode3" />
            </xsl:element>
			<xsl:element name="tag">
                <xsl:value-of select="tag" />
            </xsl:element>
			<xsl:element name="deliveryDate">
                <xsl:value-of select="deliveryDate" />
            </xsl:element>
				<xsl:element name="priceCalculationDate">
                <xsl:value-of select="priceCalculationDate" />
            </xsl:element>
            <xsl:if test="giftCardCodes!=''">
                <xsl:element name="giftCardCodes">
                    <xsl:apply-templates select="giftCardCodes/giftCardCode" />
                </xsl:element>
            </xsl:if>
        </xsl:element>
    </xsl:template>

    <xsl:template match="giftCardCodes/giftCardCode">
        <xsl:element name="giftCardCode">
            <xsl:value-of select="." />
        </xsl:element>
    </xsl:template>

    <xsl:template match="userValues/userValue">
        <xsl:element name="userValue">
            <xsl:attribute name="valueType">
                <xsl:value-of select="@valueType" />
            </xsl:attribute>
            <xsl:element name="key">
                <xsl:value-of select="key" />
            </xsl:element>
            <xsl:element name="value">
                <xsl:attribute name="contentType">
                    <xsl:value-of select="value/@contentType" />
                </xsl:attribute>
                <xsl:value-of select="value" />
            </xsl:element>
        </xsl:element>
    </xsl:template>

</xsl:stylesheet>
